#
# spec file for package fcitx-libpinyin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 12

Name:           fcitx-libpinyin
Version:        0.5.4
Release:        3.6
Summary:        Libpinyin Wrapper for Fcitx
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            https://fcitx-im.org/wiki/Libpinyin
Source0:        https://github.com/fcitx/fcitx-libpinyin/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://download.fcitx-im.org/data/model.text.20161206.tar.gz
#PATCH-FIX-UPSTREAM downgrade qt5 requirement to 5.4 since qtwebengine is available
# starting from that release
Patch0:         dictmanager-qt5.4.patch
BuildRequires:  cmake >= 3.6
BuildRequires:  fcitx-devel
BuildRequires:  fcitx-qt5-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libpinyin) >= 2.6
Provides:       locale(fcitx:zh_CN;zh_SG)
%{fcitx_requires}

%description
Fcitx-libpinyin is a Frontend of the Intelligent Pinyin IME Backend.

%prep
%autosetup -p1

cp %{SOURCE1} data

%build
%cmake
%make_build

%install
%cmake_install
%find_lang %{name}
%fdupes %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files -f %{name}.lang
%license COPYING
%dir %{_fcitx_libdir}/qt
%{_fcitx_libdir}/%{name}.so
%{_fcitx_libdir}/qt/lib%{name}-dictmanager.so
%{_fcitx_addondir}/%{name}.conf
%{_fcitx_descdir}/%{name}.desc
%{_fcitx_imicondir}/*.png
%{_fcitx_inputmethoddir}/pinyin-libpinyin.conf
%{_fcitx_inputmethoddir}/shuangpin-libpinyin.conf
%{_fcitx_inputmethoddir}/zhuyin-libpinyin.conf
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/status
%{_datadir}/icons/hicolor/48x48/status/*.png
%{_fcitx_datadir}/libpinyin

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Mar 29 2022 tiwai@suse.de
- Fix the recent TW build breakage, add icons directory to file list
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.5.4
  * Updated translation
  * Support libpinyin 2.6.0
- Drop upstream fixed
  fcitx-libpinyin-libpinyin-2.4.92-database_format.patch and
  fcitx-libpinyin-linking.patch
* Mon Mar  1 2021 Marguerite Su <i@marguerite.su>
- drop fcitx-libpinyin-0.5.3-libpinyin-2.4.92.patch
  and model19.text.tar.gz
  * can not use libpinyin data for libzhuyin
- add fcitx-libpinyin-libpinyin-2.4.92-database_format.patch
* Thu Nov 12 2020 Marguerite Su <i@marguerite.su>
- fix with libpinyin 2.4.93
  * add fcitx-libpinyin-0.5.3-libpinyin-2.4.92.patch
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add a missing build requirement.
* Wed Dec 13 2017 i@marguerite.su
- own %%{_libdir}/fcitx/qt
* Thu Sep 28 2017 hillwood@opensuse.org
- Update to 0.5.3
  * Update translation.
  * Use libpinyin 2.1.0
* Wed Aug 23 2017 hillwood@opensuse.org
- Update to 0.5.1
  * Fix a typo: continous -> continuous
  * [trans] Update Translation
  * QWidget is under QtWidgets in Qt5
* Sat Feb 11 2017 i@marguerite.su
- update version 0.5.0
  * port dictmanager to qt5
- add dictmanager-qt5.4.patch
  * downgrade qt5 requirement to 5.4 since qtwebengine is available
    at 5.4
- add fcitx-libpinyin-linking.patch
  * linking against fcitx
* Tue Jan 31 2017 i@marguerite.su
- update version 0.4.1
  * add libpinyin 1.7.0 support
  * fixed issue#21
* Fri Aug 12 2016 hillwood@opensuse.org
- Update to 0.3.91
  * update for libpinyin 1.5.91
  * [libpinyin] use only invalid pinyin in cand word string
  * [libpinyin] let's filter out ascii character for libpinyin/libpinyin#62
  * fixes https://github.com/fcitx/fcitx-libpinyin/issues/18
* Thu Dec 24 2015 i@marguerite.su
- update version 0.3.3
  * fix sogou download wrong file name encoding
  * update libpinyin requirement to 1.2.91
* Tue Aug 25 2015 i@marguerite.su
- update version 0.3.2
  * bind_textdomain_codeset to utf8
  * Close Issue#9 Disable all dictionary by default
  * add missing libintl libraries
  * no matter libpinyin tools found or not,we can build it
  * compatible with new libpinyin
  * add phrase to actual user dictionary
  * fix sogou download wrong file name encoding
* Mon Feb 17 2014 fcrozat@suse.com
- Add COPYING to %%doc
* Tue Jul 16 2013 i@marguerite.su
- update version 0.3.1
  * add new icon
  * fix import if import directory doesn't exist
  * a possible fix for Issue 699
* Mon Jul  1 2013 i@marguerite.su
- update version 0.3.0
  * Support typing mixed Chinese/English when selection is done in half way.
  * Add new dictionary manager
  * Translation Update
* Wed Jun 26 2013 i@marguerite.su
- update version 0.2.92
  * compatible with libpinyin api change 0.8.93->0.9.0
  * fix shuangpinyin might cause crash when using cloudpinyin
  * complete dictionary management
* Thu Oct 11 2012 i@marguerite.su
- update version 0.2.1
  * fix Traditional Chinese data file.
  * compatible with libpinyin 0.7.91
* Sun Sep 16 2012 i@marguerite.su
- use standard source.
* Thu Aug  2 2012 i@marguerite.su
- update version 0.2.0
  * fix builds with libpinyin 0.7.x
* Mon Jun 25 2012 i@marguerite.su
- fix fedora builds.
* Mon May 28 2012 i@marguerite.su
- bring it into DVD.
* Fri Mar  9 2012 hillwood@linuxfan.org
- update to 0.1.1
  * Portable
  * Can use traditional chinese data for pinyin and simplified
    chinese data for zhuyin
  * Use tone for zhuyin by default
  * When using Zhuyin, Enter for first candidate, Shift+Enter
    for commit English Character
* Wed Feb 29 2012 i@marguerite.su
- set _service disabled. update source from git.
* Sat Jan 28 2012 i@marguerite.su
- initial package 0.1 from git
